/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Component, OnInit } from '@angular/core';
import {NgbActiveModal} from "@ng-bootstrap/ng-bootstrap";
import {FormControl, FormGroup, Validators} from "@angular/forms";
import {SelectedFilter} from "../../model/selected-filter";
import {SelectedFilterService} from "../../services/selected-filter.service";
import {Subscription} from "rxjs";

@Component({
  selector: 'ngdb-modal-content',
  templateUrl: './save-filters.component.html',
  styleUrls: ['./save-filters.component.scss']
})
export class SaveFiltersComponent implements OnInit {

  public saveForm: FormGroup;
  public selectedFilters: Array<SelectedFilter>;
  public selectedFiltersSub: Subscription;

  constructor(public activeModal: NgbActiveModal, private selectedFilterService: SelectedFilterService) {
    this.saveForm = new FormGroup({
      name: new FormControl('', [Validators.required, Validators.pattern('[a-zA-Z0-9 ]*')])
    });

    this.selectedFiltersSub = this.selectedFilterService.selectedFilters$.subscribe((selectedFilters) => {
      this.selectedFilters = selectedFilters;
    });
  }

  ngOnInit() {
  }

  saveFilters(){
    if(this.saveForm.valid){
      this.selectedFilterService.saveFilters(this.saveForm.get('name').value);
      this.activeModal.close('Save click');
    }
  }

  ngOnDestroy(){
    if(this.selectedFiltersSub){ this.selectedFiltersSub.unsubscribe(); }
  }

}
